/*
 * Copyright 2019-2022 the Pacemaker project contributors
 *
 * The version control history for this file may have further details.
 *
 * This source code is licensed under the GNU Lesser General Public License
 * version 2.1 or later (LGPLv2.1+) WITHOUT ANY WARRANTY.
 */

#ifndef PACEMAKER_INTERNAL__H
#  define PACEMAKER_INTERNAL__H

#  include <pcmki/pcmki_acl.h>
#  include <pcmki/pcmki_cluster_queries.h>
#  include <pcmki/pcmki_fence.h>
#  include <pcmki/pcmki_output.h>
#  include <pcmki/pcmki_resource.h>
#  include <pcmki/pcmki_result_code.h>
#  include <pcmki/pcmki_rule.h>
#  include <pcmki/pcmki_sched_allocate.h>
#  include <pcmki/pcmki_sched_utils.h>
#  include <pcmki/pcmki_scheduler.h>
#  include <pcmki/pcmki_simulate.h>
#  include <pcmki/pcmki_status.h>
#  include <pcmki/pcmki_transition.h>

#endif
